@@ -1,7 +1,7 @@
 /***
 |''Name''|GroupByPlugin|
 |''Description''|Mimics allTags macro to provide ways of creating lists grouping tiddlers by any field|
-|''Version''|0.5.3|
+|''Version''|0.5.4|
 |''Author''|Jon Robson|
 |''Status''|beta|
 !Usage
@@ -67,13 +67,14 @@ var macro = config.macros.groupBy = {
 	},
 	refresh: function(place) {
 		var totalGroups = 0;
-		var paramString = $(place).attr("paramString");
+		var container = $(place).empty();
+		var paramString = container.attr("paramString");
 		var args = paramString.parseParams("name", null, true, false, true)[0];
 		var excludeValues = args.exclude || [];
 		var values = {};
-		var options = { dateFormat: $(place).attr("dateFormat") };
+		var options = { dateFormat: container.attr("dateFormat") };
 		var tiddlers = args.filter ? store.filterTiddlers(args.filter[0]) : store.getTiddlers();
-		var field = $(place).attr("fieldName");
+		var field = container.attr("fieldName");
 		var morpher = macro.morpher[field] || function(value) {
 			return value;
 		};
@@ -95,7 +96,7 @@ var macro = config.macros.groupBy = {
 				}
 			}
 		}
-		var ul = createTiddlyElement(place,"ul");
+		var ul = createTiddlyElement(place, "ul");
 		if(totalGroups === 0) {
 			createTiddlyElement(ul, "li", null, "listTitle", this.locale.noTiddlers);
 		}
