@@ -3,7 +3,7 @@ http://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.10.1
+// v0.10.3
 //
 // TODO:
 // * ensure all routes are supported
@@ -226,6 +226,10 @@ $.extend(tiddlyweb.Tiddler.prototype, {
 		var container = this.bag || this.recipe;
 		tiddler.bag = new tiddlyweb.Bag(data.bag, container.host);
 		delete data.bag;
+		tiddler.created = convertTimestamp(data.created);
+		delete data.created;
+		tiddler.modified = convertTimestamp(data.modified);
+		delete data.modified;
 		if(this.recipe) {
 			tiddler.recipe = this.recipe;
 		}
@@ -299,12 +303,25 @@ tiddlyweb._capitalize = function(str) {
 	return str.charAt(0).toUpperCase() + str.slice(1);
 };
 
+// convert YYYYMMDDhhmmss timestamp to Date instance
+var convertTimestamp = function(t) {
+	return new Date(Date.UTC(
+		parseInt(t.substr(0, 4), 10),
+		parseInt(t.substr(4, 2), 10) - 1,
+		parseInt(t.substr(6, 2), 10),
+		parseInt(t.substr(8, 2), 10),
+		parseInt(t.substr(10, 2), 10),
+		parseInt(t.substr(12, 2), 10),
+		parseInt(t.substr(14, 3) || "0", 10)
+	));
+};
+
 // adapted from Crockford (http://javascript.crockford.com/remedial.html)
 var supplant = function(str, obj) {
 	return str.replace(/{([^{}]*)}/g, function (a, b) {
 		var r = obj[b];
 		r = typeof r === "string" || typeof r === "number" ? r : a;
-		return b == "host" ? r : encodeURIComponent(r); // XXX: special-casing
+		return $.inArray(b, ["host", "query"]) != -1 ? r : encodeURIComponent(r); // XXX: special-casing
 	});
 };
 
